export default {
    "index": 28,
    "lineNumber": 3,
    "column": 1,
    "message": "'with' in strict mode"
};